@@ -1,7 +1,14 @@
 import requests
+import logging
 import json
 from airflow.models.baseoperator import BaseOperator
 
+logger = logging.getLogger(__name__)
+logger.setLevel(logging.INFO)
+handler = logging.StreamHandler()
+handler.setFormatter(logging.Formatter('%(asctime)s [%(levelname)s] %(message)s'))
+logger.addHandler(handler)
+
 
 class SparkCommandSubmitOperator(BaseOperator):
     endpoint_url: str
@@ -28,10 +35,9 @@ class SparkCommandSubmitOperator(BaseOperator):
         self.result_url = result_url
 
     def execute(self, context):
-        payload = {"type": self.code_type, "code": self.code}
+        logger.info(f'About to POST to {self.endpoint_url}')
+        payload = {"type": self.code_type, "code": self.code, "result_type": self.result_type, "result_url": self.result_url}
         json_payload = json.dumps(payload)
         headers = {"Content-Type": "application/json"}
         response = requests.post(self.endpoint_url, data=json_payload, headers=headers)
         return response.text
-
-
